@@ -28,7 +28,7 @@
 #include "download/chunkdownload.h"
 #include "peer/peermanager.h"
 
-class KUrl;
+class QUrl;
 
 namespace bt
 {
@@ -76,7 +76,7 @@ namespace bt
 		 * @param cman The ChunkManager
 		 */
 		Downloader(Torrent & tor,PeerManager & pman,ChunkManager & cman);
-		virtual ~Downloader();
+		~Downloader() override;
 		
 		/**
 		 * Set the group ID's of the webseed (for speed limits)
@@ -95,10 +95,10 @@ namespace bt
 		WebSeed* getWebSeed(Uint32 i) {return i < (Uint32)webseeds.count() ? webseeds[i] : 0;}
 		
 		/// Add a webseed
-		WebSeed* addWebSeed(const KUrl & url);
+		WebSeed* addWebSeed(const QUrl &url);
 		
 		/// Remove a webseed
-		bool removeWebSeed(const KUrl & url);
+		bool removeWebSeed(const QUrl &url);
 		
 		/// Remove all webseeds
 		void removeAllWebSeeds();
@@ -110,7 +110,7 @@ namespace bt
 		void loadWebSeeds(const QString & file);
 		
 		/// Get the number of bytes we have downloaded
-		Uint64 bytesDownloaded() const {return downloaded + curr_chunks_downloaded;}
+		Uint64 bytesDownloaded() const {return bytes_downloaded + curr_chunks_downloaded;}
 
 		/// Get the current dowload rate
 		Uint32 downloadRate() const;
@@ -140,14 +140,21 @@ namespace bt
 		 * @param chunk The chunk
 		 * @return The ChunkDownload, or 0 if no download is found
 		 */
-		ChunkDownload* getDownload(Uint32 chunk);
+		ChunkDownload* download(Uint32 chunk);
+		
+		/**
+		 * Get a download for a chunk (const version)
+		 * @param chunk The chunk
+		 * @return The ChunkDownload, or 0 if no download is found
+		 */
+		const ChunkDownload* download(Uint32 chunk) const;
 
 		/**
 		 * See if we are downloading a Chunk
 		 * @param chunk ID of Chunk
 		 * @return true if we are, false if not
 		 */
-		bool areWeDownloading(Uint32 chunk) const;
+		bool downloading(Uint32 chunk) const;
 		
 		/**
 		 * Can we download a chunk from a webseed.
@@ -194,26 +201,26 @@ namespace bt
 		/// Set the ChunkSelector, 0 means KT will reset to the default selector
 		void setChunkSelector(ChunkSelectorInterface* csel);
 		
+		/**
+		 * We got a new connection.
+		 * @param peer The PieceDownloader
+		 */
+		void addPieceDownloader(PieceDownloader* peer);
+		
+		/**
+		 * Remove a piece downloader.
+		 * @param peer The PieceDownloader
+		 */
+		void removePieceDownloader(PieceDownloader* peer);
+		
 		/// Enable or disable the use of webseeds
 		static void setUseWebSeeds(bool on);
-	public slots:
+	public Q_SLOTS:
 		/**
 		 * Update the downloader.
 		 */
 		void update();
 		
-		/**
-		 * We got a new connection.
-		 * @param peer The Peer
-		 */
-		void onNewPeer(Peer* peer);
-		
-		/**
-		 * A Peer has disconnected.
-		 * @param peer The Peer
-		 */
-		void onPeerKilled(Peer* peer);
-		
 		/**
 		 * Set the TorrentMonitor.
 		 * @param tmo 
@@ -223,16 +230,18 @@ namespace bt
 		/**
 		 * Data has been checked, and these chunks are OK.
 		 * @param ok_chunks The ok_chunks
+		 * @param from First chunk of the check
+		 * @param to Last chunk of the check
 		 */
-		void dataChecked(const BitSet & ok_chunks);
+		void dataChecked(const BitSet & ok_chunks, bt::Uint32 from, bt::Uint32 to);
 		
 		/**
 		 * Recalculate the number of bytes downloaded.
 		 */
 		void recalcDownloaded();
 		
-	private slots:
-		virtual void pieceReceived(const bt::Piece & p);
+	private Q_SLOTS:
+		void pieceReceived(const bt::Piece & p) override;
 		bool finished(ChunkDownload* c);
 		
 		/**
@@ -258,7 +267,7 @@ namespace bt
 		void chunkDownloadStarted(WebSeedChunkDownload* cd,Uint32 chunk);
 		void chunkDownloadFinished(WebSeedChunkDownload* cd,Uint32 chunk);
 		
-	signals:
+	Q_SIGNALS:
 		/**
 		 * An error occurred while we we're writing or reading from disk.
 		 * @param msg Message
@@ -283,7 +292,7 @@ namespace bt
 		Torrent & tor;
 		PeerManager & pman;
 		ChunkManager & cman;
-		Uint64 downloaded;
+		Uint64 bytes_downloaded;
 		Uint64 curr_chunks_downloaded;
 		Uint64 unnecessary_data;
 		PtrMap<Uint32,ChunkDownload> current_chunks;
