@@ -36,7 +36,7 @@ class LocalWindowTest : public QObject
 	Q_OBJECT
 public:
 	
-private slots:
+private Q_SLOTS:
 	void initTestCase()
 	{
 		bt::InitLog("localwindowtest.log");
