@@ -31,7 +31,7 @@ class SendTest : public QEventLoop
 	Q_OBJECT
 	public:
 		
-public slots:
+public Q_SLOTS:
 	void accepted()
 	{
 		incoming = new UTPSocket(bt::Globals::instance().getUTPServer().acceptedConnection());
@@ -43,7 +43,7 @@ public slots:
 		exit();
 	}
 	
-private slots:
+private Q_SLOTS:
 	void initTestCase()
 	{
 		bt::InitLog("sendtest.log");
